﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2010 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System.Collections.Generic;
using HeuristicLab.Core;
using HeuristicLab.Data;
using HeuristicLab.Persistence.Default.CompositeSerializers.Storable;
using HeuristicLab.Parameters;

namespace HeuristicLab.Problems.TravelingSalesman {

  /// <summary>
  /// A class for storing details of population diversity analysis results.
  /// </summary>
  [Item("TSPPopulationDiversityAnalysisDetails", "A class for storing details of population diversity analysis results.")]
  [StorableClass]
  public class TSPPopulationDiversityAnalysisDetails : ParameterizedNamedItem {

    public static string AverageSimilaritiesKey = "AverageSimilarities";
    public ValueParameter<ItemList<DoubleValue>> AverageSimilaritiesParameter {
      get { return (ValueParameter<ItemList<DoubleValue>>)Parameters[AverageSimilaritiesKey]; }
    }
    public ItemList<DoubleValue> AverageSimilarities {
      get { return AverageSimilaritiesParameter.Value; }
    }

    public static string AverageMaximumSimilaritiesKey = "AverageMaximumSimilarities";
    public ValueParameter<ItemList<DoubleValue>> AverageMaximumSimilaritiesParameter {
      get { return (ValueParameter<ItemList<DoubleValue>>)Parameters[AverageMaximumSimilaritiesKey]; }
    }
    public ItemList<DoubleValue> AverageMaximumSimilarities {
      get { return AverageMaximumSimilaritiesParameter.Value; }
    }

    public static string SimilaritiesKey = "Similarities";
    public ValueParameter<ItemList<DoubleMatrix>> SimilaritiesParameter {
      get { return (ValueParameter<ItemList<DoubleMatrix>>)Parameters[SimilaritiesKey]; }
    }
    public ItemList<DoubleMatrix> Similarities {
      get { return SimilaritiesParameter.Value; }
    }

    public static string MaximumSimilaritiesKey = "MaximumSimilarities";
    public ValueParameter<ItemList<DoubleArray>> MaximumSimilaritiesParameter {
      get { return (ValueParameter<ItemList<DoubleArray>>)Parameters[MaximumSimilaritiesKey]; }
    }
    public ItemList<DoubleArray> MaximumSimilarities {
      get { return MaximumSimilaritiesParameter.Value; }
    }

    public TSPPopulationDiversityAnalysisDetails()
        : base() {
      Parameters.Add(new ValueParameter<ItemList<DoubleValue>>(AverageSimilaritiesKey, "Average similarities of the solutions of the population.", new ItemList<DoubleValue>()));
      Parameters.Add(new ValueParameter<ItemList<DoubleValue>>(AverageMaximumSimilaritiesKey, "Average maximum similarities of the solutions of the population.", new ItemList<DoubleValue>()));
      Parameters.Add(new ValueParameter<ItemList<DoubleMatrix>>(SimilaritiesKey, "Similarities of the solutions of the population.", new ItemList<DoubleMatrix>()));
      Parameters.Add(new ValueParameter<ItemList<DoubleArray>>(MaximumSimilaritiesKey, "Maximum similarities of the solutions of the population.", new ItemList<DoubleArray>()));
    }

  }

}
